Locate resources — CubicWeb 3.13.2

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Web side development »

# Locate resources

`WebConfiguration.` `locate_resource`(rid)
  return the (directory, filename) where the given resource may be found

`WebConfiguration.` `locate_doc_file`(fname)
  return the directory where the given resource may be found

`WebConfiguration.` `locate_all_files`(rid, rdirectory='wdoc')
  return all files corresponding to the given resource

# Static files handling

`WebConfiguration.` `static_directory`

`WebConfiguration.` `static_file_exists`(rpath)

`WebConfiguration.` `static_file_open`(rpath, mode='wb')

`WebConfiguration.` `static_file_add`(rpath, data)

`WebConfiguration.` `static_file_del`(rpath)

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Web side development »